#
# spec file for package glslang
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define version_unconverted 3.0.g1516

Name:           glslang
Version:        3.0.g1516
Release:        lp150.1.11
Summary:        OpenGL and OpenGL ES shader front end and validator
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            https://www.khronos.org/opengles/sdk/tools/Reference-Compiler/

Source:         %name-%version.tar.xz
Patch1:         nodate.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  bison
BuildRequires:  cmake >= 2.8
BuildRequires:  gcc-c++

%description
glslang is the official reference compiler front end for the OpenGL
ES and OpenGL shading languages. It implements a strict
interpretation of the specifications for these languages.

%package devel
Summary:        OpenGL and OpenGL ES shader front end and validator
Group:          Development/Libraries/C and C++

%description devel
glslang is the official reference compiler front end for the OpenGL
ES and OpenGL shading languages. It implements a strict
interpretation of the specifications for these languages.

spirv-remap is a utility to improve compression of SPIR-V binary
files via entropy reduction, plus optional stripping of debug
information and load/store optimization. It transforms SPIR-V to
SPIR-V, remapping IDs. The resulting modules have an increased ID
range (IDs are not as tightly packed around zero), but will compress
better when multiple modules are compressed together, since
compressor's dictionary can find better cross module commonality.

%prep
%setup -q
%patch -P 1 -p1

%build
%cmake
make %{?_smp_mflags}

%install
b="%buildroot"
%cmake_install
mkdir -p "$b/%_includedir"
cp -a SPIRV glslang "$b/%_includedir/"
find "$b/%_includedir/" -type f ! -iname "*.h" -a ! -iname "*.hpp" -print -delete
ln -s SPIRV/spirv.hpp "$b/%_includedir/"
find "$b/%_includedir/" -type f -exec chmod a-x "{}" "+"
cp build/StandAlone/libglslang-default-resource-limits.so "$b/%_libdir/"

%files devel
%defattr(-,root,root)
%_bindir/gls*
%_bindir/spirv*
%_libdir/*.a
%_libdir/*resource*.so
%_includedir/*

%changelog
* Mon Aug  7 2017 jengelh@inai.de
- Update to new snapshot 3.0.g1516
  * SPV: Handle nested opaque types as function parameters.
  * SPV: Implement new extensions GL_KHX_device_group and
    GL_KHX_multiview.
  * HLSL: Fix #747: accept 'struct' in front of previously
    user-defined type name.
  * Rename KHX to EXT to match the released specs.
  * PP: Recognize the '::' token, and translate appropriately to
    GLSL/HLSL token.
  * Added 'GL_core_profile' and 'GL_compatibility_profile' macro
    definition to preamble.
  * HLSL: Add scoping operator, accept static member functions,
    and support calling them.
  * HLSL: require tessellation factors to be fixed size arrays
  * HLSL: Add namespace grammar and some basic semantics.
  * Implement the SPV_KHR_16bit_storage,
    GL_AMD_texture_gather_bias_lod, GL_AMD_gpu_shader_int16,
    GL_EXT_shadow_samplers, GL_ARB_shader_stencil_export,
    GL_OVR_multiview, GL_OVR_multiview2
    SPV_KHR_post_depth_coverage extensions.
  * Fix NULL pointer dereference in TParseContext::builtInOpCheck.
  * GLSL 4.6: Implement atomic counter ops and
    SPV_KHR_shader_atomic_counter_ops.
  * GLSL 4.6: Implement draw parameters.
  * GLSL 4.6: Implement shader group vote.
- Add nodate.diff
* Mon Feb 20 2017 jengelh@inai.de
- Update to 3.0.g1115
  * Added --vn option to generate a C header file containing a
    variable assigned to the hex representation of the shader.
  * HLSL: Type sanitization: create non-IO types for var decl and
    fn param/ret.
- Drop gccwarn.diff (resolved upstream)
* Sat Feb  4 2017 jengelh@inai.de
- Update to 3.0.g1077
  * Support SPV_NV_viewport_array2 and SPV_NV_stereo_view_rendering
  * Implement SPV_KHR_subgroup_vote
  * Add EOpD3DCOLORtoUBYTE4 decomposition
  * Add support for SPV_NV_geometry_shader_passthrough and
    SPV_NV_sample_mask_override_coverage
  * Add UAV (image) binding offset and HLSL register support
- Add gccwarn.diff
* Mon Oct 31 2016 jengelh@inai.de
- Update to 3.0g900
  * Added -x option to save SPIR-V as 32-bit hexadecimal numbers to
  a text file.
  * Add decompositions for some HLSL intrinsics.
  * HLSL: Support semantics in function parameter declarations.
  * HLSL: Map parameter qualifiers from generic to function-specific
  and entry-point specific.
  * HLSL: Add texture Load method & decomposition
  * HLSL: Add SampleLevel method
  * HLSL: Add gather, improve proto generator machine for upcoming
  2DMS/Shadow
  * HLSL: add 2DMS texture formats, and matching Load / GetDimensions
  support
  * HLSL: Add shape conversions for scalar -> vector assigments.
  * HLSL: Add string basic type and recognize string declaration
  grammar.
  * HLSL: allow multi-dimensional arrays
* Sun Jun 12 2016 jengelh@inai.de
- Update to 2.3g537
  * HLSL: Implement proper nesting of symbol-table scopes and
  identifier searching.
  * HLSL: Add all int/float/bool/uint matrix types, void for
  functions, and a few others.
  * Types: Add an isOpaque() helper
  * remapper: do not eliminate interface variables in dce by default
  * Initial implementation of direct-mapped subset of HLSL intrinsics
  with type subset.
  * SPV: Don't shadow sampler parameters when performing function calls
  * Check for linking multiple ES shaders to the same stage
  * Vulkan: Finish semantics for what creates spec-const-semantics.
  * HLSL: Add more matrix types to the grammar.
  * Full stack: distinguish between a scalar and a vector of size 1.
  * SPV: Don't emit memory barrier for ESSL barrier(), but still do
  for GLSL barrier().
  * Add support for querying vertex attributes in reflection API
  * SPV: Don't add clip/cull distance capabilities unless used.
  * Tests: Add a set of gtest-file-based HLSL tests.
  * SPV: Handle matrix's OpFConvert vector by vector.
  * HLSL: Add function call syntax and AST building.
  * SPV: Add capability ImageGatherExtended if necessary.
  * SPIR-V do not decorate: members of plain structs with location;
  non-top level members with interp.
* Tue Apr 26 2016 jengelh@inai.de
- Update to 2.3.g401
  * Fix compile error involving std::isinf
- Drop badcode.diff (merged upstream)
* Wed Feb 17 2016 jengelh@inai.de
- Initial package (version 2.3.g244) for build.opensuse.org
- Add badcode.diff
